#[repr(transparent)]pub struct HwRuc0(pub u32);Expand description
Hardware Restrict User Context 0
Tuple Fields
0: u32Implementations
Sourceimpl HwRuc0
impl HwRuc0
Sourcepub const fn set_lc_state(&mut self, val: LcState)
pub const fn set_lc_state(&mut self, val: LcState)
Life cycle state based restrictions
Sourcepub const fn boot_state(&self) -> u16
pub const fn boot_state(&self) -> u16
Temporal boot state
Sourcepub const fn set_boot_state(&mut self, val: u16)
pub const fn set_boot_state(&mut self, val: u16)
Temporal boot state
Sourcepub const fn cpu0_debug(&self) -> bool
pub const fn cpu0_debug(&self) -> bool
Disable key access when debugger is attached to CPU0 after power-up
Sourcepub const fn set_cpu0_debug(&mut self, val: bool)
pub const fn set_cpu0_debug(&mut self, val: bool)
Disable key access when debugger is attached to CPU0 after power-up
Sourcepub const fn coolflux_debug(&self) -> bool
pub const fn coolflux_debug(&self) -> bool
Disable key access when debugger is attached to COOLFLUX after power-up
Sourcepub const fn set_coolflux_debug(&mut self, val: bool)
pub const fn set_coolflux_debug(&mut self, val: bool)
Disable key access when debugger is attached to COOLFLUX after power-up
Sourcepub const fn set_dsp_debug(&mut self, val: bool)
pub const fn set_dsp_debug(&mut self, val: bool)
DSP debug status.
Sourcepub const fn access_level(&self) -> u8
pub const fn access_level(&self) -> u8
Restrict the key access based on TrustZone security level
Sourcepub const fn set_access_level(&mut self, val: u8)
pub const fn set_access_level(&mut self, val: u8)
Restrict the key access based on TrustZone security level