nxp-pac

Crates

git

Versions

mcxn947_cm33_core1

Flavors

Sr

Struct Sr 

#[repr(transparent)]
pub struct Sr(pub u32);
Status

Tuple Fields

0: u32

Implementations

Source

impl Sr

pub const fn busy(&self) -> bool

Operation in progress

pub const fn set_busy(&mut self, val: bool)

Operation in progress

pub const fn ok(&self) -> bool

Last operation successful

pub const fn set_ok(&mut self, val: bool)

Last operation successful

pub const fn error(&self) -> bool

Last operation failed

pub const fn set_error(&mut self, val: bool)

Last operation failed

pub const fn zeroized(&self) -> bool

Zeroized or Locked state

pub const fn set_zeroized(&mut self, val: bool)

Zeroized or Locked state

pub const fn rejected(&self) -> bool

Operation rejected

pub const fn set_rejected(&mut self, val: bool)

Operation rejected

pub const fn di_request(&self) -> bool

Indicates the request for data in transfer via the DIR register

pub const fn set_di_request(&mut self, val: bool)

Indicates the request for data in transfer via the DIR register

pub const fn do_request(&self) -> bool

Indicates the request for data out transfer via the DOR register

pub const fn set_do_request(&mut self, val: bool)

Indicates the request for data out transfer via the DOR register